pycocoa.geometry.Size2

Package pycocoa :: Module geometry :: Class Size2 |
[frames] | no frames]

# Class Size2

      object --+
               |
    bases._Type0 --+
                   |
                Size --+
                       |
                      Size2

Python Type, like Size, different signature.

Instance Methods
__init__(self, width=0, height=0) New Size2 from keyword arguments. |
Inherited from `Size`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Size`: `height`, `ratio`, `size`, `width` Inherited from `bases._Type0`: `NS`, `NSDelegate`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, width=0, height=0) (Constructor) |
New Size2 from keyword arguments. Overrides: object.__init__